rsinaica-defunct: Defunct Functions

rsinaica-defunctR Documentation

Defunct Functions

Description

These functions are Deprecated in this release of rsinaica, they will be removed in a future version.

Usage

sinaica_param_data(
  parameter,
  start_date,
  end_date,
  type = "Crude",
  remove_extremes = FALSE
)

rsinaica documentation built on Feb. 27, 2026, 5:08 p.m.