Learn R Programming

rsinaica (version 1.1.1)

sinaica_station_dates: Dates supported by a station

Description

Start date and end date of the range for which SINAICA has data for an air quality station

Usage

sinaica_station_dates(station_id, type = "Crude")

Value

a vector containing the date the station started reporting and end reporting date

Arguments

station_id

the numeric code corresponding to each station. See stations_sinaica for a list of stations and their ids.

type

The type of data to download. One of the following:

  • Crude - Crude data that has not been validated

  • Validated - Validated data (may not be the most up-to-date)

  • Manual - Manual data

Examples

Run this code
## id 271 is Xalostoc. See `stations_sinaica`
df <- sinaica_station_dates(271, "Manual")
head(df)

Run the code above in your browser using DataLab