Learn R Programming

rsinaica (version 1.1.0)

sinaica_station_params: Parameters supported by a station

Description

List of air quality parameters of a measuring station for which SINAICA has data

Usage

sinaica_station_params(station_id, type = "Crude")

Value

a data.frame with the parameters supported by the station

Arguments

station_id

the numeric code corresponding to each station. See stations_sinaica for a list of stations and their ids.

type

The type of data to download. One of the following:

  • Crude - Crude data that has not been validated

  • Validated - Validated data (may not be the most up-to-date)

  • Manual - Manual data

Examples

Run this code
## id 271 is Xalostoc. See `stations_sinaica`
df <- sinaica_station_params(271, "Crude")
head(df)

Run the code above in your browser using DataLab