powered by
Start date and end date of the range for which SINAICA has data for an air quality station
sinaica_station_dates(station_id, type = "Crude")
a vector containing the date the station started reporting and end reporting date
the numeric code corresponding to each station. See stations_sinaica for a list of stations and their ids.
stations_sinaica
The type of data to download. One of the following:
Crude - Crude data that has not been validated
Validated - Validated data (may not be the most up-to-date)
Manual - Manual data
## id 271 is Xalostoc. See `stations_sinaica` df <- sinaica_station_dates(271, "Manual") head(df)
Run the code above in your browser using DataLab