powered by
List of air quality parameters of a measuring station for which SINAICA has data
sinaica_station_params(station_id, type = "Crude")
a data.frame with the parameters supported by the station
the numeric code corresponding to each station. See stations_sinaica for a list of stations and their ids.
stations_sinaica
The type of data to download. One of the following:
Crude - Crude data that has not been validated
Validated - Validated data (may not be the most up-to-date)
Manual - Manual data
## id 271 is Xalostoc. See `stations_sinaica` df <- sinaica_station_params(271, "Crude") head(df)
Run the code above in your browser using DataLab